==> toycars-0.3.0.tar.gz: toycars-0.3.0/src/ToyCar.h <==
/*
	Copyright (C) 2005 by Ruben Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Zilibowitz on 31/12/04.
 */

#ifndef TOYCARS_H
#define TOYCARS_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "Vehicle.h"
#include "WheelSprite.h"
#include "ScSprite.h"

// ToyCar class

class ToyCar : public Vehicle, public ScSprite
{
public:
            ToyCar( const char * spritefilename,
                    short inFramewidth,
                    short inFrameheight,
                    
                    const char *wheelspritefilename,
                    short wheelframewidth,
                    short wheelframeheight,
                    char inWheelLayer,
                    
                    double inMass,
                    double inInertia,

                    Tuple inStartLocation,
                    double inStartOrientation,

                    double inFrontAxel,
                    double inRearAxel,
                    double inAxelWidth,
                    double inPinInset,

                    double inFrontTyreRadius,
                    double inRearTyreRadius,
                    double inFrontWheelInertia,
                    double inRearWheelInertia,

                    PacejkaCurve& inFrontWheelSlipRatioCurve,
                    PacejkaCurve& inFrontWheelSlipAngleCurve,
                    PacejkaCurve& inRearWheelSlipRatioCurve,
                    PacejkaCurve& inRearWheelSlipAngleCurve,

                    const Geom& inGeom,

                    double inDrag,
                    double inRollingResistance);
            
			ToyCar(Tuple inStartLocation, double inStartOrientation);
			ToyCar(const ToyCar& copyCar, Tuple inStartLocation, double inStartOrientation);
			
			~ToyCar();
		
	void	doDraw();
	void	process(ScFloat dt);
	
	WheelSprite*	getLeftWheelSprite() { return leftWheelSprite; }
	WheelSprite*	getRightWheelSprite() { return rightWheelSprite; }
	
private:
	PacejkaCurve*	frontSlipRatioCurve;
	PacejkaCurve*	frontSlipAngleCurve;
	PacejkaCurve*	rearSlipRatioCurve;
	PacejkaCurve*	rearSlipAngleCurve;
	
	WheelSprite*	leftWheelSprite;
	WheelSprite*	rightWheelSprite;
    
    const char      wheelLayer;
};

#endif

==> toycars-0.3.3.tar.gz: toycars-0.3.3/src/ToyCar.h <==
/*
	Copyright (C) 2005 by Ruben Henner Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Henner Zilibowitz on 31/12/04.
 */

#ifndef TOYCARS_H
#define TOYCARS_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "Vehicle.h"
#include "WheelSprite.h"
#include "ScSprite.h"

// ToyCar class

class ToyCar : public Vehicle, public ScSprite
{
public:
            ToyCar( const char * spritefilename,
                    short inFramewidth,
                    short inFrameheight,
                    
                    const char *wheelspritefilename,
                    short wheelframewidth,
                    short wheelframeheight,
                    char inWheelLayer,
                    
                    double inMass,
                    double inInertia,

                    Tuple inStartLocation,
                    double inStartOrientation,

                    double inFrontAxel,
                    double inRearAxel,
                    double inAxelWidth,
                    double inPinInset,

                    double inFrontTyreRadius,
                    double inRearTyreRadius,
                    double inFrontWheelInertia,
                    double inRearWheelInertia,

                    PacejkaCurve& inFrontWheelSlipRatioCurve,
                    PacejkaCurve& inFrontWheelSlipAngleCurve,
                    PacejkaCurve& inRearWheelSlipRatioCurve,
                    PacejkaCurve& inRearWheelSlipAngleCurve,

                    const Geom& inGeom,

                    double inDrag,
                    double inRollingResistance);
            
			ToyCar(Tuple inStartLocation, double inStartOrientation);
			ToyCar(const ToyCar& copyCar, Tuple inStartLocation, double inStartOrientation);
			
			~ToyCar();
		
	void	doDraw();
	void	process(ScFloat dt);
	
	WheelSprite*	getLeftWheelSprite() { return leftWheelSprite; }
	WheelSprite*	getRightWheelSprite() { return rightWheelSprite; }
	
private:
	PacejkaCurve*	frontSlipRatioCurve;
	PacejkaCurve*	frontSlipAngleCurve;
	PacejkaCurve*	rearSlipRatioCurve;
	PacejkaCurve*	rearSlipAngleCurve;
	
	WheelSprite*	leftWheelSprite;
	WheelSprite*	rightWheelSprite;
    
    const char      wheelLayer;
};

#endif
